Properties Methods Events Direct Link

# Class Ext.DataView.LabelEditor

Package: | Ext
Defined In: | ux-all-debug.js
Class: | DataView.LabelEditor
Extends: | Object

## Public Properties

Property | Defined By
--- | ---
| SlidingPager : Object Plugin for PagingToolbar which replaces the textfield input with a slider | DataView.LabelEditor

## Public Methods

This class has no public methods.

## Public Events

This class has no public events.